function [mu, k_x, k_g1, k_p, k_vb] = get_triode_param(tube_name)
%GET_TRIODE_PARAM Retrieve the model parameters for a specific triode tube.
%   The returned parameters can be used to parametrize the model
%   implemented by TRIODE. The following triode tubes are supported:
%
%     '12AX7'/'ECC83', '12AT7'/'ECC81', '12AU7'/'ECC82', '6DJ8'/'ECC88'
%
%   This tube parameters were determined by Norman Koren, see also
%     http://www.normankoren.com/Audio/Tubemodspice_article.html

% Revision:
%   2011/06/04 - Initial version, Matthias Hotz
%
% Copyright 2011 by Matthias Hotz
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.

switch lower(tube_name)
  case {'12ax7', 'ecc83'}
    mu = 100;
    k_x = 1.4;
    k_g1 = 1060;
    k_p = 600;
    k_vb = 300;

  case {'12at7', 'ecc81'}
    mu = 60;
    k_x = 1.35;
    k_g1 = 460;
    k_p = 300;
    k_vb = 300;

  case {'12au7', 'ecc82'}
    mu = 21.5;
    k_x = 1.30;
    k_g1 = 1180;
    k_p = 84;
    k_vb = 300;

  case {'6dj8', 'ecc88'}
    mu = 28;
    k_x = 1.30;
    k_g1 = 330;
    k_p = 320;
    k_vb = 300;

  otherwise
    error(['There are no parameters for "' tube_name '" available.']);
end
