function y = speaker_simulation(x, fs)
%SPEAKER_SIMULATION Rudimentary simulation of a speaker cabinet.
%   Extremely simplified and inaccurate simulation of the influence of
%   a speaker cabinet on the output signal of an amplifier. The simulation
%   consists of a bandpass filter which de-emphasizes the high frequency
%   content to ease the evaluation of the tube amplifier simulation output.

% Revision:
%   2011/06/08 - Initial version, Matthias Hotz
%
% Copyright 2011 by Matthias Hotz
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.

  % Second-order high-pass filter at 50Hz
  [B, A] = butter(2, 50/(fs/2), 'high');
  y = filter(B, A, x);
  
  % First-order low-pass filter at 5.5kHz
  [B, A] = butter(1, 5.5e3/(fs/2), 'low');
  y = filter(B, A, y);
  
  % First-order low-pass filter at 7kHz
  [B, A] = butter(1, 7e3/(fs/2), 'low');
  y = filter(B, A, y);

  % Normalize signal
  y = wavnorm(y, 0.99);

end
